passcode

package
v0.0.0-...-ee8fb57 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 26, 2024 License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the passcode type in the database.
	Label = "passcode"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldUserID holds the string denoting the user_id field in the database.
	FieldUserID = "user_id"
	// FieldTTL holds the string denoting the ttl field in the database.
	FieldTTL = "ttl"
	// FieldCode holds the string denoting the code field in the database.
	FieldCode = "code"
	// FieldTryCount holds the string denoting the try_count field in the database.
	FieldTryCount = "try_count"
	// FieldCreatedAt holds the string denoting the created_at field in the database.
	FieldCreatedAt = "created_at"
	// FieldUpdatedAt holds the string denoting the updated_at field in the database.
	FieldUpdatedAt = "updated_at"
	// FieldEmailID holds the string denoting the email_id field in the database.
	FieldEmailID = "email_id"
	// EdgeEmail holds the string denoting the email edge name in mutations.
	EdgeEmail = "email"
	// EdgeUser holds the string denoting the user edge name in mutations.
	EdgeUser = "user"
	// Table holds the table name of the passcode in the database.
	Table = "passcodes"
	// EmailTable is the table that holds the email relation/edge.
	EmailTable = "passcodes"
	// EmailInverseTable is the table name for the Email entity.
	// It exists in this package in order to avoid circular dependency with the "email" package.
	EmailInverseTable = "emails"
	// EmailColumn is the table column denoting the email relation/edge.
	EmailColumn = "email_id"
	// UserTable is the table that holds the user relation/edge.
	UserTable = "passcodes"
	// UserInverseTable is the table name for the User entity.
	// It exists in this package in order to avoid circular dependency with the "user" package.
	UserInverseTable = "users"
	// UserColumn is the table column denoting the user relation/edge.
	UserColumn = "user_id"
)

Variables

var (
	// DefaultCreatedAt holds the default value on creation for the "created_at" field.
	DefaultCreatedAt func() time.Time
	// DefaultUpdatedAt holds the default value on creation for the "updated_at" field.
	DefaultUpdatedAt func() time.Time
	// UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field.
	UpdateDefaultUpdatedAt func() time.Time
	// DefaultID holds the default value on creation for the "id" field.
	DefaultID func() uuid.UUID
)

Columns holds all SQL columns for passcode fields.

Functions

func And

func And(predicates ...predicate.Passcode) predicate.Passcode

And groups predicates with the AND operator between them.

func Code

func Code(v string) predicate.Passcode

Code applies equality check predicate on the "code" field. It's identical to CodeEQ.

func CodeContains

func CodeContains(v string) predicate.Passcode

CodeContains applies the Contains predicate on the "code" field.

func CodeContainsFold

func CodeContainsFold(v string) predicate.Passcode

CodeContainsFold applies the ContainsFold predicate on the "code" field.

func CodeEQ

func CodeEQ(v string) predicate.Passcode

CodeEQ applies the EQ predicate on the "code" field.

func CodeEqualFold

func CodeEqualFold(v string) predicate.Passcode

CodeEqualFold applies the EqualFold predicate on the "code" field.

func CodeGT

func CodeGT(v string) predicate.Passcode

CodeGT applies the GT predicate on the "code" field.

func CodeGTE

func CodeGTE(v string) predicate.Passcode

CodeGTE applies the GTE predicate on the "code" field.

func CodeHasPrefix

func CodeHasPrefix(v string) predicate.Passcode

CodeHasPrefix applies the HasPrefix predicate on the "code" field.

func CodeHasSuffix

func CodeHasSuffix(v string) predicate.Passcode

CodeHasSuffix applies the HasSuffix predicate on the "code" field.

func CodeIn

func CodeIn(vs ...string) predicate.Passcode

CodeIn applies the In predicate on the "code" field.

func CodeLT

func CodeLT(v string) predicate.Passcode

CodeLT applies the LT predicate on the "code" field.

func CodeLTE

func CodeLTE(v string) predicate.Passcode

CodeLTE applies the LTE predicate on the "code" field.

func CodeNEQ

func CodeNEQ(v string) predicate.Passcode

CodeNEQ applies the NEQ predicate on the "code" field.

func CodeNotIn

func CodeNotIn(vs ...string) predicate.Passcode

CodeNotIn applies the NotIn predicate on the "code" field.

func CreatedAt

func CreatedAt(v time.Time) predicate.Passcode

CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.

func CreatedAtEQ

func CreatedAtEQ(v time.Time) predicate.Passcode

CreatedAtEQ applies the EQ predicate on the "created_at" field.

func CreatedAtGT

func CreatedAtGT(v time.Time) predicate.Passcode

CreatedAtGT applies the GT predicate on the "created_at" field.

func CreatedAtGTE

func CreatedAtGTE(v time.Time) predicate.Passcode

CreatedAtGTE applies the GTE predicate on the "created_at" field.

func CreatedAtIn

func CreatedAtIn(vs ...time.Time) predicate.Passcode

CreatedAtIn applies the In predicate on the "created_at" field.

func CreatedAtLT

func CreatedAtLT(v time.Time) predicate.Passcode

CreatedAtLT applies the LT predicate on the "created_at" field.

func CreatedAtLTE

func CreatedAtLTE(v time.Time) predicate.Passcode

CreatedAtLTE applies the LTE predicate on the "created_at" field.

func CreatedAtNEQ

func CreatedAtNEQ(v time.Time) predicate.Passcode

CreatedAtNEQ applies the NEQ predicate on the "created_at" field.

func CreatedAtNotIn

func CreatedAtNotIn(vs ...time.Time) predicate.Passcode

CreatedAtNotIn applies the NotIn predicate on the "created_at" field.

func EmailID

func EmailID(v uuid.UUID) predicate.Passcode

EmailID applies equality check predicate on the "email_id" field. It's identical to EmailIDEQ.

func EmailIDEQ

func EmailIDEQ(v uuid.UUID) predicate.Passcode

EmailIDEQ applies the EQ predicate on the "email_id" field.

func EmailIDIn

func EmailIDIn(vs ...uuid.UUID) predicate.Passcode

EmailIDIn applies the In predicate on the "email_id" field.

func EmailIDIsNil

func EmailIDIsNil() predicate.Passcode

EmailIDIsNil applies the IsNil predicate on the "email_id" field.

func EmailIDNEQ

func EmailIDNEQ(v uuid.UUID) predicate.Passcode

EmailIDNEQ applies the NEQ predicate on the "email_id" field.

func EmailIDNotIn

func EmailIDNotIn(vs ...uuid.UUID) predicate.Passcode

EmailIDNotIn applies the NotIn predicate on the "email_id" field.

func EmailIDNotNil

func EmailIDNotNil() predicate.Passcode

EmailIDNotNil applies the NotNil predicate on the "email_id" field.

func HasEmail

func HasEmail() predicate.Passcode

HasEmail applies the HasEdge predicate on the "email" edge.

func HasEmailWith

func HasEmailWith(preds ...predicate.Email) predicate.Passcode

HasEmailWith applies the HasEdge predicate on the "email" edge with a given conditions (other predicates).

func HasUser

func HasUser() predicate.Passcode

HasUser applies the HasEdge predicate on the "user" edge.

func HasUserWith

func HasUserWith(preds ...predicate.User) predicate.Passcode

HasUserWith applies the HasEdge predicate on the "user" edge with a given conditions (other predicates).

func ID

func ID(id uuid.UUID) predicate.Passcode

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id uuid.UUID) predicate.Passcode

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id uuid.UUID) predicate.Passcode

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id uuid.UUID) predicate.Passcode

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...uuid.UUID) predicate.Passcode

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id uuid.UUID) predicate.Passcode

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id uuid.UUID) predicate.Passcode

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id uuid.UUID) predicate.Passcode

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...uuid.UUID) predicate.Passcode

IDNotIn applies the NotIn predicate on the ID field.

func Not

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.Passcode) predicate.Passcode

Or groups predicates with the OR operator between them.

func TTL

func TTL(v int32) predicate.Passcode

TTL applies equality check predicate on the "ttl" field. It's identical to TTLEQ.

func TTLEQ

func TTLEQ(v int32) predicate.Passcode

TTLEQ applies the EQ predicate on the "ttl" field.

func TTLGT

func TTLGT(v int32) predicate.Passcode

TTLGT applies the GT predicate on the "ttl" field.

func TTLGTE

func TTLGTE(v int32) predicate.Passcode

TTLGTE applies the GTE predicate on the "ttl" field.

func TTLIn

func TTLIn(vs ...int32) predicate.Passcode

TTLIn applies the In predicate on the "ttl" field.

func TTLLT

func TTLLT(v int32) predicate.Passcode

TTLLT applies the LT predicate on the "ttl" field.

func TTLLTE

func TTLLTE(v int32) predicate.Passcode

TTLLTE applies the LTE predicate on the "ttl" field.

func TTLNEQ

func TTLNEQ(v int32) predicate.Passcode

TTLNEQ applies the NEQ predicate on the "ttl" field.

func TTLNotIn

func TTLNotIn(vs ...int32) predicate.Passcode

TTLNotIn applies the NotIn predicate on the "ttl" field.

func TryCount

func TryCount(v int32) predicate.Passcode

TryCount applies equality check predicate on the "try_count" field. It's identical to TryCountEQ.

func TryCountEQ

func TryCountEQ(v int32) predicate.Passcode

TryCountEQ applies the EQ predicate on the "try_count" field.

func TryCountGT

func TryCountGT(v int32) predicate.Passcode

TryCountGT applies the GT predicate on the "try_count" field.

func TryCountGTE

func TryCountGTE(v int32) predicate.Passcode

TryCountGTE applies the GTE predicate on the "try_count" field.

func TryCountIn

func TryCountIn(vs ...int32) predicate.Passcode

TryCountIn applies the In predicate on the "try_count" field.

func TryCountLT

func TryCountLT(v int32) predicate.Passcode

TryCountLT applies the LT predicate on the "try_count" field.

func TryCountLTE

func TryCountLTE(v int32) predicate.Passcode

TryCountLTE applies the LTE predicate on the "try_count" field.

func TryCountNEQ

func TryCountNEQ(v int32) predicate.Passcode

TryCountNEQ applies the NEQ predicate on the "try_count" field.

func TryCountNotIn

func TryCountNotIn(vs ...int32) predicate.Passcode

TryCountNotIn applies the NotIn predicate on the "try_count" field.

func UpdatedAt

func UpdatedAt(v time.Time) predicate.Passcode

UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.

func UpdatedAtEQ

func UpdatedAtEQ(v time.Time) predicate.Passcode

UpdatedAtEQ applies the EQ predicate on the "updated_at" field.

func UpdatedAtGT

func UpdatedAtGT(v time.Time) predicate.Passcode

UpdatedAtGT applies the GT predicate on the "updated_at" field.

func UpdatedAtGTE

func UpdatedAtGTE(v time.Time) predicate.Passcode

UpdatedAtGTE applies the GTE predicate on the "updated_at" field.

func UpdatedAtIn

func UpdatedAtIn(vs ...time.Time) predicate.Passcode

UpdatedAtIn applies the In predicate on the "updated_at" field.

func UpdatedAtLT

func UpdatedAtLT(v time.Time) predicate.Passcode

UpdatedAtLT applies the LT predicate on the "updated_at" field.

func UpdatedAtLTE

func UpdatedAtLTE(v time.Time) predicate.Passcode

UpdatedAtLTE applies the LTE predicate on the "updated_at" field.

func UpdatedAtNEQ

func UpdatedAtNEQ(v time.Time) predicate.Passcode

UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.

func UpdatedAtNotIn

func UpdatedAtNotIn(vs ...time.Time) predicate.Passcode

UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.

func UserID

func UserID(v uuid.UUID) predicate.Passcode

UserID applies equality check predicate on the "user_id" field. It's identical to UserIDEQ.

func UserIDEQ

func UserIDEQ(v uuid.UUID) predicate.Passcode

UserIDEQ applies the EQ predicate on the "user_id" field.

func UserIDIn

func UserIDIn(vs ...uuid.UUID) predicate.Passcode

UserIDIn applies the In predicate on the "user_id" field.

func UserIDIsNil

func UserIDIsNil() predicate.Passcode

UserIDIsNil applies the IsNil predicate on the "user_id" field.

func UserIDNEQ

func UserIDNEQ(v uuid.UUID) predicate.Passcode

UserIDNEQ applies the NEQ predicate on the "user_id" field.

func UserIDNotIn

func UserIDNotIn(vs ...uuid.UUID) predicate.Passcode

UserIDNotIn applies the NotIn predicate on the "user_id" field.

func UserIDNotNil

func UserIDNotNil() predicate.Passcode

UserIDNotNil applies the NotNil predicate on the "user_id" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the Passcode queries.

func ByCode

func ByCode(opts ...sql.OrderTermOption) OrderOption

ByCode orders the results by the code field.

func ByCreatedAt

func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption

ByCreatedAt orders the results by the created_at field.

func ByEmailField

func ByEmailField(field string, opts ...sql.OrderTermOption) OrderOption

ByEmailField orders the results by email field.

func ByEmailID

func ByEmailID(opts ...sql.OrderTermOption) OrderOption

ByEmailID orders the results by the email_id field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByTTL

func ByTTL(opts ...sql.OrderTermOption) OrderOption

ByTTL orders the results by the ttl field.

func ByTryCount

func ByTryCount(opts ...sql.OrderTermOption) OrderOption

ByTryCount orders the results by the try_count field.

func ByUpdatedAt

func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption

ByUpdatedAt orders the results by the updated_at field.

func ByUserField

func ByUserField(field string, opts ...sql.OrderTermOption) OrderOption

ByUserField orders the results by user field.

func ByUserID

func ByUserID(opts ...sql.OrderTermOption) OrderOption

ByUserID orders the results by the user_id field.

Jump to