Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.Passcode) predicate.Passcode
- func Code(v string) predicate.Passcode
- func CodeContains(v string) predicate.Passcode
- func CodeContainsFold(v string) predicate.Passcode
- func CodeEQ(v string) predicate.Passcode
- func CodeEqualFold(v string) predicate.Passcode
- func CodeGT(v string) predicate.Passcode
- func CodeGTE(v string) predicate.Passcode
- func CodeHasPrefix(v string) predicate.Passcode
- func CodeHasSuffix(v string) predicate.Passcode
- func CodeIn(vs ...string) predicate.Passcode
- func CodeLT(v string) predicate.Passcode
- func CodeLTE(v string) predicate.Passcode
- func CodeNEQ(v string) predicate.Passcode
- func CodeNotIn(vs ...string) predicate.Passcode
- func CreatedAt(v time.Time) predicate.Passcode
- func CreatedAtEQ(v time.Time) predicate.Passcode
- func CreatedAtGT(v time.Time) predicate.Passcode
- func CreatedAtGTE(v time.Time) predicate.Passcode
- func CreatedAtIn(vs ...time.Time) predicate.Passcode
- func CreatedAtLT(v time.Time) predicate.Passcode
- func CreatedAtLTE(v time.Time) predicate.Passcode
- func CreatedAtNEQ(v time.Time) predicate.Passcode
- func CreatedAtNotIn(vs ...time.Time) predicate.Passcode
- func EmailID(v uuid.UUID) predicate.Passcode
- func EmailIDEQ(v uuid.UUID) predicate.Passcode
- func EmailIDIn(vs ...uuid.UUID) predicate.Passcode
- func EmailIDIsNil() predicate.Passcode
- func EmailIDNEQ(v uuid.UUID) predicate.Passcode
- func EmailIDNotIn(vs ...uuid.UUID) predicate.Passcode
- func EmailIDNotNil() predicate.Passcode
- func HasEmail() predicate.Passcode
- func HasEmailWith(preds ...predicate.Email) predicate.Passcode
- func HasUser() predicate.Passcode
- func HasUserWith(preds ...predicate.User) predicate.Passcode
- func ID(id uuid.UUID) predicate.Passcode
- func IDEQ(id uuid.UUID) predicate.Passcode
- func IDGT(id uuid.UUID) predicate.Passcode
- func IDGTE(id uuid.UUID) predicate.Passcode
- func IDIn(ids ...uuid.UUID) predicate.Passcode
- func IDLT(id uuid.UUID) predicate.Passcode
- func IDLTE(id uuid.UUID) predicate.Passcode
- func IDNEQ(id uuid.UUID) predicate.Passcode
- func IDNotIn(ids ...uuid.UUID) predicate.Passcode
- func Not(p predicate.Passcode) predicate.Passcode
- func Or(predicates ...predicate.Passcode) predicate.Passcode
- func TTL(v int32) predicate.Passcode
- func TTLEQ(v int32) predicate.Passcode
- func TTLGT(v int32) predicate.Passcode
- func TTLGTE(v int32) predicate.Passcode
- func TTLIn(vs ...int32) predicate.Passcode
- func TTLLT(v int32) predicate.Passcode
- func TTLLTE(v int32) predicate.Passcode
- func TTLNEQ(v int32) predicate.Passcode
- func TTLNotIn(vs ...int32) predicate.Passcode
- func TryCount(v int32) predicate.Passcode
- func TryCountEQ(v int32) predicate.Passcode
- func TryCountGT(v int32) predicate.Passcode
- func TryCountGTE(v int32) predicate.Passcode
- func TryCountIn(vs ...int32) predicate.Passcode
- func TryCountLT(v int32) predicate.Passcode
- func TryCountLTE(v int32) predicate.Passcode
- func TryCountNEQ(v int32) predicate.Passcode
- func TryCountNotIn(vs ...int32) predicate.Passcode
- func UpdatedAt(v time.Time) predicate.Passcode
- func UpdatedAtEQ(v time.Time) predicate.Passcode
- func UpdatedAtGT(v time.Time) predicate.Passcode
- func UpdatedAtGTE(v time.Time) predicate.Passcode
- func UpdatedAtIn(vs ...time.Time) predicate.Passcode
- func UpdatedAtLT(v time.Time) predicate.Passcode
- func UpdatedAtLTE(v time.Time) predicate.Passcode
- func UpdatedAtNEQ(v time.Time) predicate.Passcode
- func UpdatedAtNotIn(vs ...time.Time) predicate.Passcode
- func UserID(v uuid.UUID) predicate.Passcode
- func UserIDEQ(v uuid.UUID) predicate.Passcode
- func UserIDIn(vs ...uuid.UUID) predicate.Passcode
- func UserIDIsNil() predicate.Passcode
- func UserIDNEQ(v uuid.UUID) predicate.Passcode
- func UserIDNotIn(vs ...uuid.UUID) predicate.Passcode
- func UserIDNotNil() predicate.Passcode
- func ValidColumn(column string) bool
- type OrderOption
- func ByCode(opts ...sql.OrderTermOption) OrderOption
- func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByEmailField(field string, opts ...sql.OrderTermOption) OrderOption
- func ByEmailID(opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByTTL(opts ...sql.OrderTermOption) OrderOption
- func ByTryCount(opts ...sql.OrderTermOption) OrderOption
- func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByUserField(field string, opts ...sql.OrderTermOption) OrderOption
- func ByUserID(opts ...sql.OrderTermOption) OrderOption
Constants ¶
const ( // Label holds the string label denoting the passcode type in the database. Label = "passcode" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldUserID holds the string denoting the user_id field in the database. FieldUserID = "user_id" // FieldTTL holds the string denoting the ttl field in the database. FieldTTL = "ttl" // FieldCode holds the string denoting the code field in the database. FieldCode = "code" // FieldTryCount holds the string denoting the try_count field in the database. FieldTryCount = "try_count" // FieldCreatedAt holds the string denoting the created_at field in the database. FieldCreatedAt = "created_at" // FieldUpdatedAt holds the string denoting the updated_at field in the database. FieldUpdatedAt = "updated_at" // FieldEmailID holds the string denoting the email_id field in the database. FieldEmailID = "email_id" // EdgeEmail holds the string denoting the email edge name in mutations. EdgeEmail = "email" // EdgeUser holds the string denoting the user edge name in mutations. EdgeUser = "user" // Table holds the table name of the passcode in the database. Table = "passcodes" // EmailTable is the table that holds the email relation/edge. EmailTable = "passcodes" // EmailInverseTable is the table name for the Email entity. // It exists in this package in order to avoid circular dependency with the "email" package. EmailInverseTable = "emails" // EmailColumn is the table column denoting the email relation/edge. EmailColumn = "email_id" // UserTable is the table that holds the user relation/edge. UserTable = "passcodes" // UserInverseTable is the table name for the User entity. // It exists in this package in order to avoid circular dependency with the "user" package. UserInverseTable = "users" // UserColumn is the table column denoting the user relation/edge. UserColumn = "user_id" )
Variables ¶
var ( // DefaultCreatedAt holds the default value on creation for the "created_at" field. DefaultCreatedAt func() time.Time // DefaultUpdatedAt holds the default value on creation for the "updated_at" field. DefaultUpdatedAt func() time.Time // UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field. UpdateDefaultUpdatedAt func() time.Time // DefaultID holds the default value on creation for the "id" field. DefaultID func() uuid.UUID )
var Columns = []string{ FieldID, FieldUserID, FieldTTL, FieldCode, FieldTryCount, FieldCreatedAt, FieldUpdatedAt, FieldEmailID, }
Columns holds all SQL columns for passcode fields.
Functions ¶
func CodeContains ¶
CodeContains applies the Contains predicate on the "code" field.
func CodeContainsFold ¶
CodeContainsFold applies the ContainsFold predicate on the "code" field.
func CodeEqualFold ¶
CodeEqualFold applies the EqualFold predicate on the "code" field.
func CodeHasPrefix ¶
CodeHasPrefix applies the HasPrefix predicate on the "code" field.
func CodeHasSuffix ¶
CodeHasSuffix applies the HasSuffix predicate on the "code" field.
func CreatedAt ¶
CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.
func CreatedAtEQ ¶
CreatedAtEQ applies the EQ predicate on the "created_at" field.
func CreatedAtGT ¶
CreatedAtGT applies the GT predicate on the "created_at" field.
func CreatedAtGTE ¶
CreatedAtGTE applies the GTE predicate on the "created_at" field.
func CreatedAtIn ¶
CreatedAtIn applies the In predicate on the "created_at" field.
func CreatedAtLT ¶
CreatedAtLT applies the LT predicate on the "created_at" field.
func CreatedAtLTE ¶
CreatedAtLTE applies the LTE predicate on the "created_at" field.
func CreatedAtNEQ ¶
CreatedAtNEQ applies the NEQ predicate on the "created_at" field.
func CreatedAtNotIn ¶
CreatedAtNotIn applies the NotIn predicate on the "created_at" field.
func EmailID ¶
EmailID applies equality check predicate on the "email_id" field. It's identical to EmailIDEQ.
func EmailIDIsNil ¶
EmailIDIsNil applies the IsNil predicate on the "email_id" field.
func EmailIDNEQ ¶
EmailIDNEQ applies the NEQ predicate on the "email_id" field.
func EmailIDNotIn ¶
EmailIDNotIn applies the NotIn predicate on the "email_id" field.
func EmailIDNotNil ¶
EmailIDNotNil applies the NotNil predicate on the "email_id" field.
func HasEmailWith ¶
HasEmailWith applies the HasEdge predicate on the "email" edge with a given conditions (other predicates).
func HasUserWith ¶
HasUserWith applies the HasEdge predicate on the "user" edge with a given conditions (other predicates).
func TryCount ¶
TryCount applies equality check predicate on the "try_count" field. It's identical to TryCountEQ.
func TryCountEQ ¶
TryCountEQ applies the EQ predicate on the "try_count" field.
func TryCountGT ¶
TryCountGT applies the GT predicate on the "try_count" field.
func TryCountGTE ¶
TryCountGTE applies the GTE predicate on the "try_count" field.
func TryCountIn ¶
TryCountIn applies the In predicate on the "try_count" field.
func TryCountLT ¶
TryCountLT applies the LT predicate on the "try_count" field.
func TryCountLTE ¶
TryCountLTE applies the LTE predicate on the "try_count" field.
func TryCountNEQ ¶
TryCountNEQ applies the NEQ predicate on the "try_count" field.
func TryCountNotIn ¶
TryCountNotIn applies the NotIn predicate on the "try_count" field.
func UpdatedAt ¶
UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.
func UpdatedAtEQ ¶
UpdatedAtEQ applies the EQ predicate on the "updated_at" field.
func UpdatedAtGT ¶
UpdatedAtGT applies the GT predicate on the "updated_at" field.
func UpdatedAtGTE ¶
UpdatedAtGTE applies the GTE predicate on the "updated_at" field.
func UpdatedAtIn ¶
UpdatedAtIn applies the In predicate on the "updated_at" field.
func UpdatedAtLT ¶
UpdatedAtLT applies the LT predicate on the "updated_at" field.
func UpdatedAtLTE ¶
UpdatedAtLTE applies the LTE predicate on the "updated_at" field.
func UpdatedAtNEQ ¶
UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.
func UpdatedAtNotIn ¶
UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.
func UserID ¶
UserID applies equality check predicate on the "user_id" field. It's identical to UserIDEQ.
func UserIDIsNil ¶
UserIDIsNil applies the IsNil predicate on the "user_id" field.
func UserIDNotIn ¶
UserIDNotIn applies the NotIn predicate on the "user_id" field.
func UserIDNotNil ¶
UserIDNotNil applies the NotNil predicate on the "user_id" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the Passcode queries.
func ByCode ¶
func ByCode(opts ...sql.OrderTermOption) OrderOption
ByCode orders the results by the code field.
func ByCreatedAt ¶
func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
ByCreatedAt orders the results by the created_at field.
func ByEmailField ¶
func ByEmailField(field string, opts ...sql.OrderTermOption) OrderOption
ByEmailField orders the results by email field.
func ByEmailID ¶
func ByEmailID(opts ...sql.OrderTermOption) OrderOption
ByEmailID orders the results by the email_id field.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByTTL ¶
func ByTTL(opts ...sql.OrderTermOption) OrderOption
ByTTL orders the results by the ttl field.
func ByTryCount ¶
func ByTryCount(opts ...sql.OrderTermOption) OrderOption
ByTryCount orders the results by the try_count field.
func ByUpdatedAt ¶
func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
ByUpdatedAt orders the results by the updated_at field.
func ByUserField ¶
func ByUserField(field string, opts ...sql.OrderTermOption) OrderOption
ByUserField orders the results by user field.
func ByUserID ¶
func ByUserID(opts ...sql.OrderTermOption) OrderOption
ByUserID orders the results by the user_id field.